import {
  IEventParam, Metadata, IDictionary, I18n, Loader, DatasourceFactory, dayjs as moment, Router,
} from '@zeedhi/core';
import {
  Card, IterableComponentRender, Tabs, Tab, LoadingService, Increment, Button, Form, Select,
  Text, DialogService,
} from '@zeedhi/common';
import { BottomSheet } from '@zeedhi/zd-bottom-sheet';
import { HttpCRUDTranslator } from '@/http-crud-translator/http-crud-translator';

export class EfetivosController {
  private showEditServicoEfetivos = false;

  private showClientesEfetivos = false;

  private utilities = Loader.getInstance('Utilities');

  private appController = Loader.getInstance('AppController');

  private serviceSelected = {
    CDSERVFILI: '',
    CDTIPOCARD: '',
    DTCARDIAPME: '',
    TOTAL: 0,
  };

  private periodo = {
    DTINICIAL: '',
    DTFINAL: '',
  };

  private editingClientName = '';

  get isVisibleEfetivosList() {
    return !this.showEditServicoEfetivos && !this.showClientesEfetivos;
  }

  public get setFilterEfetivos() {
    if (localStorage.getItem('hasImportedData') === 'true') {
      return {
        CDFILIAL: localStorage.getItem('CDFILIALLOGADA') || '',
        DTCARDIAPME: this.utilities.getAllDatesInRange(this.periodo.DTINICIAL, this.periodo.DTFINAL),
      };
    }
    return {
      CDFILIAL: localStorage.getItem('CDFILIALLOGADA') || '',
      DTINICIAL: this.periodo.DTINICIAL || '',
      DTFINAL: this.periodo.DTFINAL || '',
    };
  }

  public clickBackEditServico() {
    this.showEditServicoEfetivos = false;
    const servicos = Metadata.getInstance<IterableComponentRender>('iterableCardsEfetivos');
    servicos.reload();
  }

  public async clickCardServicoEfetivos({ component }: IEventParam<Card>) {
    LoadingService.show(' ');
    this.showEditServicoEfetivos = true;
    const tabsServicos = Metadata.getInstance<Tabs>('tabsServicos');
    const servicosRender = Metadata.getInstance<IterableComponentRender>('iterableCardsEfetivos');
    if (tabsServicos.tabs.length > 0) {
      await Promise.all(tabsServicos.tabs.map(async (tab: IDictionary) => {
        await tab.children.map(async (child: IDictionary) => {
          await tab.removeChild(child.name);
        });
      })).then(() => {
        tabsServicos.tabs = [];
        tabsServicos.tabs = servicosRender.datasource.data.map((row) => this.newTabs(row));
      });
    } else tabsServicos.tabs = servicosRender.datasource.data.map((row) => this.newTabs(row));
    const index = component.name.split('-')[1];
    tabsServicos.activeTab = await tabsServicos.tabs.findIndex((tab) => tab.children[0].name === `tagTab-${index}`);
    LoadingService.hide();
  }

  private newTabs(row: IDictionary) {
    return new Tab({
      name: `${row.CDSERVFILI}`,
      tabTitle: `${row.CDSERVFILI} - ${row.NMSERVICO}`,
      children: [
        {
          allowDuplicate: true,
          name: `tagTab-${row.CDSERVFILI}_${row.NRCARDPME}_${row.NRCARDIAPME}`,
          component: 'ZdTag',
          tag: 'div',
          children: [
            {
              name: `formEditService-${row.CDSERVFILI}_${row.DTCARDIAPME}_${row.NRCARDIAPME}`,
              component: 'ZdForm',
              children: [
                {
                  allowDuplicate: true,
                  name: 'SERVICO',
                  component: 'ZdText',
                  text: `${I18n.translate('Serviço: ')}${row.CDSERVFILI} - ${row.NMSERVICO}`,
                  grid: {
                    cols: 12,
                  },
                },
                {
                  allowDuplicate: true,
                  name: 'DATA_EXTENSO',
                  component: 'ZdText',
                  // label: 'Data',
                  // value: `${row.DATA_EXTENSO}`,
                  text: `${I18n.translate('Data: ')}${this.utilities.formatDate(row.DTCARDIAPME)} - 
                    ${this.utilities.getDateFormat(row.DTCARDIAPME, 'dddd')}`,
                  grid: {
                    cols: 12,
                  },
                },
                {
                  allowDuplicate: true,
                  isVisible: false,
                  name: 'CDTIPOCARD',
                  component: 'ZdTextInput',
                  readonly: true,
                  label: 'Código Tipo de Cardápio',
                  value: `${row.CDTIPOCARD}`,
                  grid: {
                    cols: 12,
                  },
                },
                {
                  allowDuplicate: true,
                  name: 'TIPOCARD',
                  component: 'ZdText',
                  // label: 'Tipo de Cardápio',
                  // value: `${row.CDTIPOCARD} - ${row.NMTIPOCARD}`,
                  text: `${I18n.translate('Tipo de Cardápio')}: ${row.CDTIPOCARD} - ${row.NMTIPOCARD}`,
                  grid: {
                    cols: 12,
                  },
                },
                {
                  allowDuplicate: true,
                  name: 'DSCARDPME',
                  component: 'ZdText',
                  // label: 'Cardápio',
                  // value: `${row.DSCARDPME}`,
                  text: `${I18n.translate('Cardápio: ')} ${row.DSCARDPME}`,
                  grid: {
                    cols: 12,
                  },
                },
                {
                  allowDuplicate: true,
                  name: 'QTCLIEFECPME',
                  component: 'ZdIncrement',
                  label: 'Clientes',
                  clearable: false,
                  step: 1,
                  events: {
                    change: '{{EfetivosController.changeEfetivosServico}}',
                  },
                  validations: {
                    required: {
                      message: ' ',
                    },
                    min: {
                      limit: 0,
                    },
                  },
                  mask: {
                    decimalPlaces: 0,
                  },
                  value: row.QTCLIEFECPME,
                  grid: {
                    cols: 12,
                  },
                },
                {
                  allowDuplicate: true,
                  name: 'QTFUNEFECPME',
                  component: 'ZdIncrement',
                  label: 'Funcionários',
                  clearable: false,
                  step: 1,
                  events: {
                    change: '{{EfetivosController.changeEfetivosServico}}',
                  },
                  validations: {
                    required: {
                      message: ' ',
                    },
                    min: {
                      limit: 0,
                    },
                  },
                  mask: {
                    decimalPlaces: 0,
                  },
                  value: row.QTFUNEFECPME,
                  grid: {
                    cols: 12,
                  },
                },
                {
                  allowDuplicate: true,
                  name: 'QTDOAEFECPME',
                  component: 'ZdIncrement',
                  label: 'Doação',
                  clearable: false,
                  step: 1,
                  events: {
                    change: '{{EfetivosController.changeEfetivosServico}}',
                  },
                  validations: {
                    required: {
                      message: ' ',
                    },
                    min: {
                      limit: 0,
                    },
                  },
                  mask: {
                    decimalPlaces: 0,
                  },
                  value: row.QTDOAEFECPME,
                  grid: {
                    cols: 12,
                  },
                },
                {
                  allowDuplicate: true,
                  name: 'QTCOMEFECPME',
                  component: 'ZdNumber',
                  readonly: true,
                  showBorder: false,
                  label: 'Total de Efetivos',
                  value: row.QTCOMEFECPME,
                  cssClass: 'readonly-text',
                  align: 'center',
                  mask: {
                    decimalPlaces: 0,
                  },
                  grid: {
                    cols: 12,
                  },
                },
                {
                  allowDuplicate: true,
                  name: 'CDFILCENTPME',
                  isVisible: false,
                  component: 'ZdTextInput',
                  value: `${row.CDFILCENTPME}`,
                },
                {
                  allowDuplicate: true,
                  name: 'NRCARDPME',
                  isVisible: false,
                  component: 'ZdTextInput',
                  value: `${row.NRCARDPME}`,
                },
                {
                  allowDuplicate: true,
                  name: 'NRCARDIAPME',
                  isVisible: false,
                  component: 'ZdTextInput',
                  value: `${row.NRCARDIAPME}`,
                },
                {
                  allowDuplicate: true,
                  name: 'DTCARDIAPME',
                  isVisible: false,
                  component: 'ZdTextInput',
                  value: `${row.DTCARDIAPME}`,
                },
                {
                  allowDuplicate: true,
                  name: 'CDSERVFILI',
                  isVisible: false,
                  component: 'ZdTextInput',
                  value: `${row.CDSERVFILI}`,
                },
              ],
            },
            {
              allowDuplicate: true,
              name: 'clientesList',
              component: 'ZdList',
              divided: true,
              dense: true,
              twoLine: true,
              cssClass: 'zd-mb-4',
              items: [
                {
                  allowDuplicate: true,
                  name: 'clientesItem',
                  component: 'ZdListItem',
                  title: 'Clientes',
                  subtitle: `${I18n.translate('Ajustar Quantidades')}`,
                  rightField: {
                    allowDuplicate: true,
                    name: 'rightIcon1',
                    component: 'ZdButton',
                    iconName: 'mdi-tune',
                    icon: true,
                    flat: true,
                    events: {
                      click: '{{EfetivosController.openClientesEfetivos}}',
                    },
                  },
                },
              ],
            },
            {
              name: `salvarEditServicoBtn-${row.CDSERVFILI}_${row.DTCARDIAPME}_${row.NRCARDIAPME}`,
              component: 'ZdButton',
              label: 'Salvar',
              block: true,
              fixed: true,
              bottom: true,
              disabled: true,
              ligth: false,
              dark: true,
              events: {
                click: '{{EfetivosController.salvarEditServico}}',
              },
              cssStyle: {
                right: '0px',
              },
            },
          ],
        },
      ],
    });
  }

  public salvarEditServico({ component }: IEventParam<Button>) {
    const form = component.parent?.getChildInstance<Form>(component.parent?.children[0].name);
    if (form?.validate()) {
      const v = form?.value;
      const cdfilial = localStorage.getItem('CDFILIALLOGADA') || '';
      const dataset = [
        {
          CDFILIAL: cdfilial,
          ...form?.value,
          KEY: `${v.CDFILCENTPME}${v.NRCARDPME}${v.NRCARDIAPME}${cdfilial}${v.CDSERVFILI}${v.CDTIPOCARD}`,
        },
      ];
      LoadingService.show(' ');
      HttpCRUDTranslator.post('/servicosCardapioEfetivos/update', { requestType: 'DataSet', dataset })
        .then(async (response: IDictionary) => {
          if (!response.data.error) {
            this.serviceSelected = {
              CDSERVFILI: form?.value.CDSERVFILI,
              CDTIPOCARD: form?.value.CDTIPOCARD,
              DTCARDIAPME: form?.value.DTCARDIAPME,
              TOTAL: form?.value.QTCOMEFECPME,
            };
            const tabsServicos = Metadata.getInstance<Tabs>('tabsServicos');
            const clientesRender = Metadata.getInstance<IterableComponentRender>('iterableCardsClientesEfetivos');
            const cloneConfig = clientesRender.datasource.clone();
            const cloneDs = DatasourceFactory.factory(cloneConfig);
            await cloneDs.get().then(async (clientes: IDictionary[]) => {
              if (clientes.length > 0) {
                clientes.forEach((cliente: IDictionary) => {
                  cliente.QTCOMEFCLPME = 0;
                  cliente.QTDOAEFCLPME = 0;
                  cliente.QTFUNEFCLPME = 0;
                  cliente.TOTAL = 0;
                  cliente.changed = true;
                });
                const clientePrincipal = clientes.filter((cliente: IDictionary) => cliente.IDCLIENPRIN === 'S');
                if (clientePrincipal.length > 0) {
                  const index = clientes.indexOf(clientePrincipal[0]);
                  clientePrincipal[0].QTCOMEFCLPME = form?.value.QTCLIEFECPME;
                  clientePrincipal[0].QTDOAEFCLPME = form?.value.QTDOAEFECPME;
                  clientePrincipal[0].QTFUNEFCLPME = form?.value.QTFUNEFECPME;
                  clientePrincipal[0].TOTAL = form?.value.QTCOMEFECPME;
                  if (index !== -1) {
                    const [aux] = clientePrincipal;
                    clientes[index] = aux;
                  }
                } else {
                  clientes[0].QTCOMEFCLPME = form?.value.QTCLIEFECPME;
                  clientes[0].QTDOAEFCLPME = form?.value.QTDOAEFECPME;
                  clientes[0].QTFUNEFCLPME = form?.value.QTFUNEFECPME;
                  clientes[0].TOTAL = form?.value.QTCOMEFECPME;
                }
                await HttpCRUDTranslator.post('/clientesDoServicoEfetivos/update',
                  { requestType: 'DataSet', dataset: [...clientes] })
                  .then(() => {
                    if (!response.data.error) {
                      // this.utilities.showAlert('successSave', 'SUCCESS_SAVE', 'green');
                      this.utilities.showAlert('alertQuantClientes', 'SETUP_CLIENT_QUANT', 'warning');
                      component.disabled = true;
                      // tabsServicos.nextTab();
                    } else {
                      const mensagem = response.data.error;
                      this.utilities.showAlert('errorSave', I18n.translate(mensagem), 'error');
                    }
                  }).catch((error: string) => {
                    this.utilities.showAlert('alert', error, 'error');
                  });
              } else {
                this.utilities.showAlert('successSave', 'SUCCESS_SAVE', 'green');
                component.disabled = true;
                tabsServicos.nextTab();
              }
            });
          } else {
            const mensagem = response.data.error;
            this.utilities.showAlert('errorSave', I18n.translate(mensagem), 'error');
          }
        }).catch((error: string) => {
          this.utilities.showAlert('alert', error, 'error');
        }).finally(() => {
          LoadingService.hide();
        });
    }
  }

  public changeEfetivosServico({ component }: IEventParam<Increment>) {
    const form = component.parent as Form;
    if (form.validate()) {
      form.value.QTCOMEFECPME = form.value.QTCLIEFECPME + form.value.QTFUNEFECPME + form.value.QTDOAEFECPME;
      const size = component.parent?.parent?.childrenInstances?.length || 0;
      const btn = component.parent?.parent?.childrenInstances[size - 1] as Button;
      btn.disabled = false;
    }
  }

  public openClientesEfetivos() {
    this.showEditServicoEfetivos = false;
    this.showClientesEfetivos = true;
    const tabsServicos = Metadata.getInstance<Tabs>('tabsServicos');
    const selectedTab = tabsServicos.tabs[tabsServicos.activeTab] as Tab;
    // const children = selectedTab?.childrenInstances[1]?.childrenInstances;
    const tag = selectedTab?.childrenInstances.find((data: IDictionary) => data.component === 'ZdTag');
    const formName = tag?.childrenInstances.find((data: IDictionary) => data.component === 'ZdForm');
    const form = formName as Form;
    this.serviceSelected = {
      CDSERVFILI: form.value.CDSERVFILI,
      CDTIPOCARD: form.value.CDTIPOCARD,
      DTCARDIAPME: form.value.DTCARDIAPME,
      TOTAL: form.value.QTCOMEFECPME,
    };
    const clientesRender = Metadata.getInstance<IterableComponentRender>('iterableCardsClientesEfetivos');
    clientesRender.reload();
  }

  public clickBackClientesEfetivos() {
    this.showClientesEfetivos = false;
    this.showEditServicoEfetivos = true;
  }

  public get setFilterClientesEfetivos() {
    return {
      CDFILIAL: localStorage.getItem('CDFILIALLOGADA') || '',
      DTINICIAL: this.serviceSelected.DTCARDIAPME || '',
      DTFINAL: this.serviceSelected.DTCARDIAPME || '',
      PERIODO: 5,
      CDSERVFILI: this.serviceSelected.CDSERVFILI || '',
      CDTIPOCARD: this.serviceSelected.CDTIPOCARD || '',
    };
  }

  public clickFilterEfetivos() {
    const bottomSheet = Metadata.getInstance<BottomSheet>('filterSheet');
    const filial = Metadata.getInstance<Select>('CDFILIALLOGADA');
    const hasImportedData = localStorage.getItem('hasImportedData');
    if (filial.value && filial.value.CDFILCENTPME && filial.value.CDFILIAL !== filial.value.CDFILCENTPME
      && hasImportedData === 'true') {
      this.utilities.fillDatesFilter(bottomSheet);
      bottomSheet.isVisible = true;
      bottomSheet.isOpen = true;
    }
  }

  public clickCloseFilterBtn() {
    const bottomSheet = Metadata.getInstance<BottomSheet>('filterSheet');
    bottomSheet.isVisible = false;
    bottomSheet.isOpen = false;
  }

  public setPeriodoEfetivos({ component }: IEventParam<Button>) {
    const form = component.parent as Form;
    if (form.validate()) {
      if (form.value.PERIODO.length === 2) {
        let format = 'YYYY-MM-DD';
        if (form.value.PERIODO[1].charAt(2) === '/') format = 'DD/MM/YYYY';
        const dtini = moment(form.value.PERIODO[0], format);
        const dtfin = moment(form.value.PERIODO[1], format);
        if (dtini.isValid() && dtfin.isValid()) {
          if (dtini >= moment(localStorage.getItem('DATA_INICIAL'), 'DD/MM/YYYY')
            && dtfin <= moment(localStorage.getItem('DATA_FINAL'), 'DD/MM/YYYY')) {
            this.loadEfetivos(dtini.format('DD/MM/YYYY'), dtfin.format('DD/MM/YYYY'), form.value.search);
            const bottomSheet = Metadata.getInstance<BottomSheet>('filterSheet');
            bottomSheet.isVisible = false;
            bottomSheet.isOpen = false;
          } else this.utilities.showAlert('errorPeriodFilter', 'DATE_NOT_IN_PERIOD', 'error');
        } else this.utilities.showAlert('errorDateFilter', 'INVALID_DATE', 'error');
      } else this.utilities.showAlert('errorFilter', 'FILTER_2_DATES', 'error');
    }
  }

  public loadEfetivos(inicio: string, fim: string, search: string) {
    this.periodo.DTINICIAL = inicio;
    this.periodo.DTFINAL = fim;
    const efetivos = Metadata.getInstance<IterableComponentRender>('iterableCardsEfetivos');
    efetivos.datasource.search = search;
    // efetivos.datasource.order = [];
    efetivos.reload();
  }

  public openFilter() {
    if (!localStorage.getItem('DATA_INICIAL') && !localStorage.getItem('DATA_FINAL')) {
      const btn = Metadata.getInstance<Button>('filterEfetivosButton');
      btn.click();
    } else if (localStorage.getItem('CDFILIALLOGADA') !== 'null') {
      const dtIni = localStorage.getItem('DATA_INICIAL') || '';
      const dtFin = localStorage.getItem('DATA_FINAL') || '';
      this.loadEfetivos(dtIni, dtFin, '');
    }
  }

  public async clickCardCliente({ component }: IEventParam<Card>) {
    const bottomSheet = Metadata.getInstance<BottomSheet>('editClientSheet');
    const [cdcliente, cdservfili] = component.name.split('-')[1].split('_');
    const clientsCards = Metadata.getInstance<IterableComponentRender>('iterableCardsClientesEfetivos');
    const clientSelected = await clientsCards.datasource.data.find(
      (data: IDictionary) => data.CDCLIENTE === cdcliente && data.CDSERVFILI === cdservfili,
    );
    this.editingClientName = clientSelected?.NMRAZSOCCLIE;
    const form = Metadata.getInstance<Form>('formEditClient');
    form.value.TOTAL = clientSelected?.TOTAL || 0;
    form.value.QTCOMEFCLPME = clientSelected?.QTCOMEFCLPME || 0;
    form.value.QTDOAEFCLPME = clientSelected?.QTDOAEFCLPME || 0;
    form.value.QTFUNEFCLPME = clientSelected?.QTFUNEFCLPME || 0;
    form.value.CDCLIENTE = clientSelected?.CDCLIENTE;
    form.value.CDFILCENTPME = clientSelected?.CDFILCENTPME;
    form.value.DTEFETCLPME = clientSelected?.DTEFETCLPME;
    bottomSheet.isVisible = true;
    bottomSheet.isOpen = true;
  }

  public clickCloseEditClient() {
    const bottomSheet = Metadata.getInstance<BottomSheet>('editClientSheet');
    bottomSheet.isVisible = false;
    bottomSheet.isOpen = false;
  }

  public ordenaServicosEfetivos({ component }: IEventParam<Button>) {
    const { name } = component;
    const efetivos = Metadata.getInstance<IterableComponentRender>('iterableCardsEfetivos');
    const ds = efetivos.datasource;
    const order = ds.getOrderByColumn(name);
    if (order) {
      if (order === 'desc') ds.addOrder(name, 'asc');
      else ds.addOrder(name, 'desc');
    } else ds.addOrder(name, 'desc');
  }

  public setValueEfetivos({ component }: IEventParam<Text>) {
    let value = component.name.split('-')[1].split('_')[2];
    // if (value !== 'null') {
    if (value === 'null') value = '0';
    component.text = `Total de Efetivos: ${value}`;
    // }
  }

  public salvarEditClient({ component }: IEventParam<Button>) {
    const form = component.parent as Form;
    if (form.validate()) {
      const clientes = Metadata.getInstance<IterableComponentRender>('iterableCardsClientesEfetivos');
      const cliente = clientes.datasource.data.find(
        (data) => data.CDSERVFILI === this.serviceSelected.CDSERVFILI && data.CDCLIENTE === form.value.CDCLIENTE,
      );
      if (cliente) {
        cliente.TOTAL = form.value.TOTAL;
        cliente.QTCOMEFCLPME = form.value.QTCOMEFCLPME;
        cliente.QTDOAEFCLPME = form.value.QTDOAEFCLPME;
        cliente.QTFUNEFCLPME = form.value.QTFUNEFCLPME;
      }
      const bottomSheet = Metadata.getInstance<BottomSheet>('editClientSheet');
      bottomSheet.isVisible = false;
      bottomSheet.isOpen = false;
    }
  }

  public changeEfetivosClient({ component }: IEventParam<Increment>) {
    const form = component.parent as Form;
    if (form.validate()) form.value.TOTAL = form.value.QTCOMEFCLPME + form.value.QTFUNEFCLPME + form.value.QTDOAEFCLPME;
  }

  public async salvarClients() {
    const clientes = Metadata.getInstance<IterableComponentRender>('iterableCardsClientesEfetivos');
    if (clientes.datasource.data.length > 0) {
      let total = 0;
      await clientes.datasource.data.forEach((row) => {
        total += row.TOTAL;
      });
      if (this.serviceSelected.TOTAL === total) {
        const dataset = [...clientes.datasource.data];
        LoadingService.show(' ');
        HttpCRUDTranslator.post('/clientesDoServicoEfetivos/update', { requestType: 'DataSet', dataset })
          .then((response: IDictionary) => {
            if (!response.data.error) {
              this.utilities.showAlert('successSave', 'SUCCESS_SAVE', 'green');
              this.clickBackClientesEfetivos();
            } else {
              const mensagem = response.data.error;
              this.utilities.showAlert('errorSave', I18n.translate(mensagem), 'error');
            }
          }).catch((error: string) => {
            this.utilities.showAlert('alert', error, 'error');
          }).finally(() => {
            LoadingService.hide();
          });
      } else {
        DialogService.show({
          name: 'erroSomaClientes',
          type: 'error',
          title: I18n.translate('scm::ATTENTION'),
          text: I18n.translate('scm::STAFF_CLIENT_SUM_NOT_EQUAL'),
          buttons: [
            {
              allowDuplicate: true,
              name: 'ok',
              component: 'ZdButton',
              label: I18n.translate('scm::OK'),
              events: { click: () => DialogService.hide() },
            },
          ],
        });
      }
    } else {
      this.clickBackClientesEfetivos();
    }
  }

  public checkAccess() {
    if (localStorage.getItem('hasImportedData') === 'true') {
      const filial = Metadata.getInstance<Select>('CDFILIALLOGADA');
      if (filial.value) {
        let text = '';
        if (!filial.value.CDFILCENTPME) {
          text = 'scm::BLOCK_ACCESS_EFETIVOS_1';
          DialogService.show({
            name: 'blockAccessInventory',
            type: 'error',
            title: I18n.translate('scm::ATTENTION'),
            text: I18n.translate(text),
            buttons: [
              {
                name: 'ok',
                component: 'ZdButton',
                label: I18n.translate('scm::OK'),
                events: {
                  click: () => {
                    DialogService.hide();
                    Router.push('/');
                  },
                },
              },
            ],
          });
        } else if (filial.value.CDFILIAL === filial.value.CDFILCENTPME) {
          text = 'scm::BLOCK_ACCESS_EFETIVOS';
          DialogService.show({
            name: 'blockAccessInventory',
            type: 'error',
            title: I18n.translate('scm::ATTENTION'),
            text: I18n.translate(text),
            buttons: [
              {
                name: 'ok',
                component: 'ZdButton',
                label: I18n.translate('scm::OK'),
                events: {
                  click: () => {
                    DialogService.hide();
                    Router.push('/');
                  },
                },
              },
            ],
          });
        }
      } else {
        this.appController.unidadeLogadaIsValid();
      }
    } else {
      DialogService.show({
        name: 'needImport',
        type: 'error',
        title: I18n.translate('scm::ERROR'),
        text: I18n.translate('scm::NEED_IMPORT'),
        buttons: [
          {
            name: 'ok',
            component: 'ZdButton',
            label: I18n.translate('scm::OK'),
            events: {
              click: () => {
                DialogService.hide();
                Router.push('/importacao');
              },
            },
          },
        ],
      });
    }
  }

  public setFormattedDate({ component }: IEventParam<Text>) {
    const len = component.name.split('_').length;
    const value = component.name.split('_')[len - 1] || '';
    component.text = this.utilities.formatDate(value);
  }
}
